@@ -4,8 +4,9 @@ import pulumi
 import pulumi_gcp as gcp
 from pulumi import automation 
 from pulumi.automation import LocalWorkspace, LocalWorkspaceOptions, ProjectBackend
-from infrastructure.pulumi_infra_config import PulumiInfraConfig
 
+from .pulumi_infra_config import PulumiInfraConfig
+from .models.pulumi import PreviewResult, UpResult, DestroyResult, RefreshResult
 
 class PulumiExecutionInterface():
     
@@ -51,22 +52,28 @@ class PulumiExecution(PulumiExecutionInterface):
   
         self.stack.workspace.install_plugin("gcp", "v7.3.1")
         
-    def execute(self):
-        self.stack.up(on_output=print)
+    def execute(self) -> UpResult:
+        output = self.stack.up()
+        return output
         
-    def destroy(self):
-        self.stack.destroy(on_output=print)
+    def destroy(self) -> DestroyResult:
+        output = self.stack.destroy()
+        return output
         
-    def preview(self):
-        self.stack.preview(on_output=print)
+    def preview(self) -> PreviewResult:
+        output = self.stack.preview()
+        return output
     
-    def refresh(self):
-        self.stack.refresh(on_output=print)
+    def refresh(self) -> RefreshResult:
+        output = self.stack.refresh()
+        return output
         
     def cancel(self):
-        self.stack.cancel()
+        output = self.stack.cancel()
+        return output
         
-    def destroy_stack(self):
-        self.stack.destroy(on_output=print)
+    def destroy_stack(self) -> DestroyResult:
+        output = self.stack.destroy()
+        return output
     
-        
\ No newline at end of file
+    
\ No newline at end of file
